A wrapper for the docker API.
A wrapper for the docker API.
(api-call {:keys [url] :as endpoint} path request)Call the docker api via http.
Call the docker api via http.
(api-call-fn command
{:keys [query-params path method json-body headers return
base64-json-headers doc doc-url]
:or {method :get}
:as api-def})Given an api call definition map, generate a function that will call the api function.
Given an api call definition map, generate a function that will call the api function.
(api-map command
{:keys [query-params path method json-body headers return]
:as api-def})Given an api call definition map, generate a function that will return the map.
Given an api call definition map, generate a function that will return the map.
(api-map-args command)Define a schema for a map argument.
Define a schema for a map argument.
(api-map-return command)Define a schema for a map return arguments.
Define a schema for a map return arguments.
Given an api command keyword and a map of arguments, return an http request map. The request has a :path element specifying the http path.
Given an api command keyword and a map of arguments, return an http
request map. The request has a :path element specifying the http
path.
## Function Signatures
- Keyword {Any Any} -> {Any Any}(api-req-method command
{:keys [query-params path method body json-body headers return
base64-json-headers doc doc-url]
:or {method :get}
:as api-def})Given an api call definition map, generate a function that will return an http request map.
Given an api call definition map, generate a function that will return an http request map.
(auth-map {:as params :keys [username password email server]})## Function Signatures - (com.palletops.docker/api-map-args :auth) -> (com.palletops.docker/api-map-return :auth)
(base64-json-header [k v])Convert a map entry into a base64 json.
Convert a map entry into a base64 json.
(build endpoint {:as params :keys [t q nocache content-type]})Build an image from Dockerfile via stdin
Build an image from Dockerfile via stdin
See http://docs.docker.io/reference/api/docker_remote_api_v1.11/#build-an-image-from-dockerfile-via-stdin
## Function Signatures
- {(optional-key :keystore-pass) (maybe java.lang.String), (optional-key :keystore) (maybe (either java.lang.String java.security.KeyStore)), (optional-key :trust-store) (maybe (either java.lang.String java.security.KeyStore)), (optional-key :insecure?) Bool, (optional-key :trust-store-pass) (maybe java.lang.String), :url java.lang.String} (com.palletops.docker/api-map-args :build) -> (com.palletops.docker/api-map-return :build)(build-map {:as params :keys [t q nocache]})## Function Signatures - (com.palletops.docker/api-map-args :build) -> (com.palletops.docker/api-map-return :build)
(coerce-json-body {:keys [coerce]}
{:keys [body status] :as resp}
keyword?
strict?
&
[charset])(commit-map {:as params
:keys [Env Memory MemorySwap DisableNetwork OpenStdin Tty m
WorkingDir AttachStderr AttachStdout Hostname ExposedPorts
author User AttachStdin container StdinOnce Volumes repo tag
PortSpecs Cmd]})## Function Signatures - (com.palletops.docker/api-map-args :commit) -> (com.palletops.docker/api-map-return :commit)
(container-changes-map {:as params :keys [id]})## Function Signatures - (com.palletops.docker/api-map-args :container-changes) -> (com.palletops.docker/api-map-return :container-changes)
(container-copy-map {:as params :keys [id Resource]})## Function Signatures - (com.palletops.docker/api-map-args :container-copy) -> (com.palletops.docker/api-map-return :container-copy)
(container-create-map
{:as params
:keys [Env Memory MemorySwap DisableNetwork OpenStdin Image Tty name
WorkingDir AttachStderr AttachStdout Hostname ExposedPorts User
VolumesFrom Dns AttachStdin StdinOnce Volumes PortSpecs Cmd]})## Function Signatures - (com.palletops.docker/api-map-args :container-create) -> (com.palletops.docker/api-map-return :container-create)
(container-delete-map {:as params :keys [force v id]})## Function Signatures - (com.palletops.docker/api-map-args :container-delete) -> (com.palletops.docker/api-map-return :container-delete)
(container-export-map {:as params :keys [id]})## Function Signatures - (com.palletops.docker/api-map-args :container-export) -> (com.palletops.docker/api-map-return :container-export)
(container-kill-map {:as params :keys [signal id]})## Function Signatures - (com.palletops.docker/api-map-args :container-kill) -> (com.palletops.docker/api-map-return :container-kill)
(container-logs-map {:as params :keys [follow stdout stderr timestamps id]})## Function Signatures - (com.palletops.docker/api-map-args :container-logs) -> (com.palletops.docker/api-map-return :container-logs)
(container-map {:as params :keys [id]})## Function Signatures - (com.palletops.docker/api-map-args :container) -> (com.palletops.docker/api-map-return :container)
(container-processes-map {:as params :keys [ps_args id]})## Function Signatures - (com.palletops.docker/api-map-args :container-processes) -> (com.palletops.docker/api-map-return :container-processes)
(container-restart-map {:as params :keys [t id]})## Function Signatures - (com.palletops.docker/api-map-args :container-restart) -> (com.palletops.docker/api-map-return :container-restart)
(container-start-map
{:as params :keys [id Binds LxcConf PortBindings PublishAllPorts Privileged]})## Function Signatures - (com.palletops.docker/api-map-args :container-start) -> (com.palletops.docker/api-map-return :container-start)
(container-stop-map {:as params :keys [t id]})## Function Signatures - (com.palletops.docker/api-map-args :container-stop) -> (com.palletops.docker/api-map-return :container-stop)
(container-wait-map {:as params :keys [id]})## Function Signatures - (com.palletops.docker/api-map-args :container-wait) -> (com.palletops.docker/api-map-return :container-wait)
(containers-map {:as params :keys [all limit since before size]})## Function Signatures - (com.palletops.docker/api-map-args :containers) -> (com.palletops.docker/api-map-return :containers)
Call the docker API based on a map specifying the command to be called, and and arguments.
Call the docker API based on a map specifying the command to be called,
and and arguments.
## Function Signatures
- {:url String} {Any Any} -> {Any Any}(events-map {:as params :keys [since until]})## Function Signatures - (com.palletops.docker/api-map-args :events) -> (com.palletops.docker/api-map-return :events)
(image-create endpoint {:as params :keys [repo tag registry fromSource]})Create an image, either by pull it from the registry or by importing it.
See http://docs.docker.io/reference/api/docker_remote_api_v1.11/#create-an-image
Create an image, either by pull it from the registry or by importing it.
See http://docs.docker.io/reference/api/docker_remote_api_v1.11/#create-an-image
## Function Signatures
- {(optional-key :keystore-pass) (maybe java.lang.String), (optional-key :keystore) (maybe (either java.lang.String java.security.KeyStore)), (optional-key :trust-store) (maybe (either java.lang.String java.security.KeyStore)), (optional-key :insecure?) Bool, (optional-key :trust-store-pass) (maybe java.lang.String), :url java.lang.String} (com.palletops.docker/api-map-args :image-create) -> (com.palletops.docker/api-map-return :image-create)(image-create-map {:as params :keys [repo tag registry fromSource]})## Function Signatures - (com.palletops.docker/api-map-args :image-create) -> (com.palletops.docker/api-map-return :image-create)
(image-delete-map {:as params :keys [force noprune name]})## Function Signatures - (com.palletops.docker/api-map-args :image-delete) -> (com.palletops.docker/api-map-return :image-delete)
(image-history-map {:as params :keys [name]})## Function Signatures - (com.palletops.docker/api-map-args :image-history) -> (com.palletops.docker/api-map-return :image-history)
(image-insert-map {:as params :keys [path url name]})## Function Signatures - (com.palletops.docker/api-map-args :image-insert) -> (com.palletops.docker/api-map-return :image-insert)
(image-map {:as params :keys [name]})## Function Signatures - (com.palletops.docker/api-map-args :image) -> (com.palletops.docker/api-map-return :image)
(image-push-map {:as params :keys [registry name]})## Function Signatures - (com.palletops.docker/api-map-args :image-push) -> (com.palletops.docker/api-map-return :image-push)
(image-tag-map {:as params :keys [force repo name]})## Function Signatures - (com.palletops.docker/api-map-args :image-tag) -> (com.palletops.docker/api-map-return :image-tag)
(images-map {:as params :keys []})## Function Signatures - (com.palletops.docker/api-map-args :images) -> (com.palletops.docker/api-map-return :images)
(info-map {:as params :keys []})## Function Signatures - (com.palletops.docker/api-map-args :info) -> (com.palletops.docker/api-map-return :info)
(json-decode-stream parser)Return a lazy sequence of json objects returned by the parser.
Return a lazy sequence of json objects returned by the parser.
(load-images-map {:as params :keys []})## Function Signatures - (com.palletops.docker/api-map-args :load-images) -> (com.palletops.docker/api-map-return :load-images)
(ping-map {:as params :keys []})## Function Signatures - (com.palletops.docker/api-map-args :ping) -> (com.palletops.docker/api-map-return :ping)
(read-stream-records is break-fn)(read-stream-records is break-fn filter-fn)Read stream record from is until it is closed, or break-fn called with the stream type keyword and stream content returns true. break-fn is called with :entry before anything is read.
Read stream record from is until it is closed, or break-fn called with the stream type keyword and stream content returns true. break-fn is called with :entry before anything is read.
(repo-images-map {:as params :keys [name]})## Function Signatures - (com.palletops.docker/api-map-args :repo-images) -> (com.palletops.docker/api-map-return :repo-images)
(version-map {:as params :keys []})## Function Signatures - (com.palletops.docker/api-map-args :version) -> (com.palletops.docker/api-map-return :version)
(wrap-request request)Returns a HTTP request function coresponding to the given core client.
Returns a HTTP request function coresponding to the given core client.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |